import { Module } from '@nestjs/common';
import { MongooseModule } from '@nestjs/mongoose';
import { Episode, EpisodeSchema } from 'schemas/entity/episode.entity';
import { AppService } from './app.service';
import { EpisodeService } from './episode/episode.service';
import { GraphQLModule } from '@nestjs/graphql';
import { join } from 'path';
import { EpisodeResolver } from './episode/episode.resolver';

@Module({
  imports: [
    MongooseModule.forFeature([{ name: Episode.name, schema: EpisodeSchema }]),
    MongooseModule.forRoot('mongodb://localhost:27017/test'),
    GraphQLModule.forRoot({
      debug: false,
      playground: true,
      autoSchemaFile: join(process.cwd(), 'src/schema.gql'),
      installSubscriptionHandlers: true,
    }),
  ],
  providers: [AppService, EpisodeService, EpisodeResolver],
})
export class AppModule {}
